AppwrouterRequest class

A class that represents the request object.

Constructors

AppwrouterRequest({required String bodyRaw, required dynamic body, required Map<String, dynamic> headers, required dynamic scheme, required String method, required String url, required String host, required int port, required String path, required String queryString, required Map<String, dynamic> query, Map<String, dynamic> params = const <String, dynamic>{}})
A class that represents the request object.
const
AppwrouterRequest.parse(dynamic req)
Parsing the Request from Appwrite,
factory

Properties

body → dynamic
The body of the request.
final
bodyRaw String
The raw body of the request.
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, dynamic>
The headers of the request.
final
host String
The host of the request.
final
method String
The method of the request.
final
params Map<String, dynamic>
The params of the request.
final
path String
The path of the request.
final
port int
The port of the request.
final
query Map<String, dynamic>
The query of the request.
final
queryString String
The query string of the request.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheme → dynamic
The scheme of the request.
final
url String
The url of the request.
final

Methods

copyWith({String? bodyRaw, dynamic body, Map<String, dynamic>? headers, dynamic scheme, String? method, String? url, String? host, int? port, String? path, String? queryString, Map<String, dynamic>? query, Map<String, dynamic>? params}) AppwrouterRequest
Copy with
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited