AppwrouterResponse class

A class that represents the response object.

Constructors

AppwrouterResponse({required dynamic empty, required dynamic json, required dynamic redirect, required dynamic send})
A class that represents the response object.
AppwrouterResponse.parse(dynamic res)
Parsing the Response from Appwrite,
factory

Properties

empty → dynamic
The empty response.
final
hashCode int
The hash code for this object.
no setterinherited
json → dynamic
The json response.
final
redirect → dynamic
The redirect response.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
send → dynamic
The send response.
final

Methods

copyWith({dynamic empty, dynamic json, dynamic redirect, dynamic send}) AppwrouterResponse
Copy with
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited