EventType enum

Event type from Appwrite Function triggered by event

Inheritance
Available extensions

Values

create → const EventType

Create event type

const EventType(code: 'create')
update → const EventType

Read event type

const EventType(code: 'update')
delete → const EventType

Delete event type

const EventType(code: 'delete')

Properties

code String
The code of the EventType
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromCode(String code) EventType
Parsing from String code to EventType

Constants

values → const List<EventType>
A constant List of the values in this enum, in order of their declaration.