Initialize class

A class for handling the Middleware in Function

Constructors

Initialize({required dynamic req, required dynamic res, required dynamic log, required dynamic error, required Future<Client> onMiddleware(OnMiddleware), required Future onNext(AppwrouterRequest req, AppwrouterResponse res, Client client), required Future<void> onError(dynamic)})
A class for handling the Middleware in Function

Properties

error → dynamic
An error from Appwrite Function Context
final
hashCode int
The hash code for this object.
no setterinherited
log → dynamic
A log from Appwrite Function Context
final
onError Future<void> Function(dynamic)
An error function
final
onMiddleware Future<Client> Function(OnMiddleware)
A middleware function
final
onNext Future Function(AppwrouterRequest req, AppwrouterResponse res, Client client)
A next function
final
req AppwrouterRequest
A request instance parsed from Appwrite Function Context
final
res AppwrouterResponse
A result instance parsed from Appwrite Function Context
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited