MethodType enum

Enumerate the HTTP methods.

Inheritance
Available extensions

Values

get → const MethodType

The GET method requests a representation of the specified resource.

const MethodType(code: 'GET')
post → const MethodType

The POST method is used to submit an entity to the specified resource, often causing a change in state or side effects on the server.

const MethodType(code: 'POST')
put → const MethodType

The PUT method replaces all current representations of the target resource with the request payload.

const MethodType(code: 'PUT')
delete → const MethodType

The DELETE method deletes the specified resource.

const MethodType(code: 'DELETE')
patch → const MethodType

The PATCH method is used to apply partial modifications to a resource.

const MethodType(code: 'PATCH')

Properties

code String
The code of the enum
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromCode(String method) MethodType
Parsing String code to MethodType

Constants

values → const List<MethodType>
A constant List of the values in this enum, in order of their declaration.