Route class

A route class

Constructors

Route()

Properties

hashCode int
The hash code for this object.
no setterinherited
methods Map<MethodType, RouteHandler>
The holder for all handler functions that depends on the method type
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addMethod(MethodType method, RouteHandler handler) → void
A method for create new handler that dedicated for this method type
getMethod(MethodType method) RouteHandler
A getter method
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited