RouteMatchHandler class

A class for handling property for matching route.

Constructors

RouteMatchHandler({required Map<String, dynamic> params, required RouteHandler handler})
A class for handling property for matching route.

Properties

handler RouteHandler
A handler function
final
hashCode int
The hash code for this object.
no setterinherited
params Map<String, dynamic>
A map of all params
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited