Appwrouter class
A router for appwrite cloud functions
Constructors
- Appwrouter()
-
Singleton instance of the router
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
versions
↔ Map<
String, VersionedRoutes> -
Registration of all versions, routes and handlers
getter/setter pair
Methods
-
delete(
{required String version, required String path, required RouteHandler handler}) → void - DELETE registration method
-
get(
{required String version, required String path, required RouteHandler handler}) → void - GET registration method
-
handleRequest(
{required HandleRequest handlerequest}) → Future - A function to handle the request
-
matchRoute(
{required String version, required MethodType method, required String path}) → RouteMatchHandler? - A function to match the route
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(
{required String version, required String path, required RouteHandler handler}) → void - PATCH registration method
-
post(
{required String version, required String path, required RouteHandler handler}) → void - POST registration method
-
put(
{required String version, required String path, required RouteHandler handler}) → void - PUT registration method
-
register(
{required String version, required MethodType method, required String path, required RouteHandler handler}) → void - A method for registration for version routes
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → Appwrouter
-
Singleton instance of the router
no setter