HandleRequest class
A class for handling the Request in Function
Constructors
- HandleRequest({required AppwrouterRequest req, required AppwrouterResponse res, required dynamic log, required dynamic error, required Client client})
- A class for handling the Request in Function
Properties
- client → Client
-
A client instance from Appwrite SDK
final
- error → dynamic
-
An error from Appwrite Function Context
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- log → dynamic
-
A log from Appwrite Function Context
final
- req → AppwrouterRequest
-
A request parsed from Appwrite Function Context
final
- res → AppwrouterResponse
-
A response parsed from Appwrite Function Context
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited