MatchRoute class
A class for handling property for matching route.
Constructors
- MatchRoute({required String version, required String method, required String path})
- A class for handling property for matching route.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- method → String
-
The method of type such as
GET,POST, and etc.final - path → String
-
The string path of the route.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → String
-
The version of all routes
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited