OnMiddleware class
A property of middleware
Constructors
-
OnMiddleware({required AppwrouterRequest req, required AppwrouterResponse res, required dynamic log, required dynamic error, required MethodType method, required TriggeredType triggeredType, required String path, EventType? eventType, Map<
String, dynamic> ? eventMap}) - A property of middleware
Properties
- error → dynamic
-
An error from Appwrite Function Context
final
-
eventMap
→ Map<
String, dynamic> ? -
Parsed event map from the 'x-appwrite-event' header into a Map
final
- eventType → EventType?
-
An event type such as create, update, delete
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- log → dynamic
-
A log from Appwrite Function Context
final
- method → MethodType
-
A method type
final
- path → String
-
A path of the request
final
- req → AppwrouterRequest
-
A request from Appwrite Function Context
final
- res → AppwrouterResponse
-
A response from Appwrite Function Context
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- triggeredType → TriggeredType
-
A triggered type such as HTTP, Event, Schedule
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited